/*******************************************************************************
* File Name: PinOutCc.c  
* Version 2.5
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "PinOutCc.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        PinOutCc_PC =   (PinOutCc_PC & \
                                (uint32)(~(uint32)(PinOutCc_DRIVE_MODE_IND_MASK << (PinOutCc_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (PinOutCc_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: PinOutCc_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void PinOutCc_Write(uint8 value) 
{
    uint8 drVal = (uint8)(PinOutCc_DR & (uint8)(~PinOutCc_MASK));
    drVal = (drVal | ((uint8)(value << PinOutCc_SHIFT) & PinOutCc_MASK));
    PinOutCc_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: PinOutCc_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  PinOutCc_DM_STRONG     Strong Drive 
*  PinOutCc_DM_OD_HI      Open Drain, Drives High 
*  PinOutCc_DM_OD_LO      Open Drain, Drives Low 
*  PinOutCc_DM_RES_UP     Resistive Pull Up 
*  PinOutCc_DM_RES_DWN    Resistive Pull Down 
*  PinOutCc_DM_RES_UPDWN  Resistive Pull Up/Down 
*  PinOutCc_DM_DIG_HIZ    High Impedance Digital 
*  PinOutCc_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void PinOutCc_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(PinOutCc__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: PinOutCc_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro PinOutCc_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 PinOutCc_Read(void) 
{
    return (uint8)((PinOutCc_PS & PinOutCc_MASK) >> PinOutCc_SHIFT);
}


/*******************************************************************************
* Function Name: PinOutCc_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 PinOutCc_ReadDataReg(void) 
{
    return (uint8)((PinOutCc_DR & PinOutCc_MASK) >> PinOutCc_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(PinOutCc_INTSTAT) 

    /*******************************************************************************
    * Function Name: PinOutCc_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 PinOutCc_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(PinOutCc_INTSTAT & PinOutCc_MASK);
		PinOutCc_INTSTAT = maskedStatus;
        return maskedStatus >> PinOutCc_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
