/*******************************************************************************
* File Name: PinOutTc.c  
* Version 2.5
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "PinOutTc.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        PinOutTc_PC =   (PinOutTc_PC & \
                                (uint32)(~(uint32)(PinOutTc_DRIVE_MODE_IND_MASK << (PinOutTc_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (PinOutTc_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: PinOutTc_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void PinOutTc_Write(uint8 value) 
{
    uint8 drVal = (uint8)(PinOutTc_DR & (uint8)(~PinOutTc_MASK));
    drVal = (drVal | ((uint8)(value << PinOutTc_SHIFT) & PinOutTc_MASK));
    PinOutTc_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: PinOutTc_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  PinOutTc_DM_STRONG     Strong Drive 
*  PinOutTc_DM_OD_HI      Open Drain, Drives High 
*  PinOutTc_DM_OD_LO      Open Drain, Drives Low 
*  PinOutTc_DM_RES_UP     Resistive Pull Up 
*  PinOutTc_DM_RES_DWN    Resistive Pull Down 
*  PinOutTc_DM_RES_UPDWN  Resistive Pull Up/Down 
*  PinOutTc_DM_DIG_HIZ    High Impedance Digital 
*  PinOutTc_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void PinOutTc_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(PinOutTc__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: PinOutTc_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro PinOutTc_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 PinOutTc_Read(void) 
{
    return (uint8)((PinOutTc_PS & PinOutTc_MASK) >> PinOutTc_SHIFT);
}


/*******************************************************************************
* Function Name: PinOutTc_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 PinOutTc_ReadDataReg(void) 
{
    return (uint8)((PinOutTc_DR & PinOutTc_MASK) >> PinOutTc_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(PinOutTc_INTSTAT) 

    /*******************************************************************************
    * Function Name: PinOutTc_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 PinOutTc_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(PinOutTc_INTSTAT & PinOutTc_MASK);
		PinOutTc_INTSTAT = maskedStatus;
        return maskedStatus >> PinOutTc_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
