/*******************************************************************************
* File Name: SCBUART_SPI_UART_INT.c
* Version 1.20
*
* Description:
*  This file provides the source code to the Interrupt Service Routine for
*  the SCB Component in SPI and UART modes.
*
* Note:
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "SCBUART_PVT.h"
#include "SCBUART_SPI_UART_PVT.h"


/*******************************************************************************
* Function Name: SCBUART_SPI_UART_ISR
********************************************************************************
*
* Summary:
*  Handles the Interrupt Service Routine for the SCB SPI or UART modes.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
CY_ISR(SCBUART_SPI_UART_ISR)
{
#if(SCBUART_INTERNAL_RX_SW_BUFFER_CONST)
    uint32 locHead;
    uint32 dataRx;
#endif /* (SCBUART_INTERNAL_RX_SW_BUFFER_CONST) */

#if(SCBUART_INTERNAL_TX_SW_BUFFER_CONST)
    uint32 locTail;
#endif /* (SCBUART_INTERNAL_TX_SW_BUFFER_CONST) */

    if(NULL != SCBUART_customIntrHandler)
    {
        SCBUART_customIntrHandler();
    }

    #if(SCBUART_CHECK_SPI_WAKE_ENABLE)
    {
        /* Clear SPI wakeup source */
        SCBUART_ClearSpiExtClkInterruptSource(SCBUART_INTR_SPI_EC_WAKE_UP);
    }
    #endif

    #if(SCBUART_CHECK_RX_SW_BUFFER)
    {
        if(SCBUART_CHECK_INTR_RX_MASKED(SCBUART_INTR_RX_NOT_EMPTY))
        {
            while(0u != SCBUART_GET_RX_FIFO_ENTRIES)
            {
                /* Get data from RX FIFO */
                dataRx = SCBUART_RX_FIFO_RD_REG;

                /* Move local head index */
                locHead = (SCBUART_rxBufferHead + 1u);

                /* Adjust local head index */
                if(SCBUART_RX_BUFFER_SIZE == locHead)
                {
                    locHead = 0u;
                }

                if(locHead == SCBUART_rxBufferTail)
                {
                    /* Overflow: through away new data */
                    SCBUART_rxBufferOverflow = (uint8) SCBUART_INTR_RX_OVERFLOW;
                }
                else
                {
                    /* Store received data */
                    SCBUART_PutWordInRxBuffer(locHead, dataRx);

                    /* Move head index */
                    SCBUART_rxBufferHead = locHead;
                }
            }

            SCBUART_ClearRxInterruptSource(SCBUART_INTR_RX_NOT_EMPTY);
        }
    }
    #endif


    #if(SCBUART_CHECK_TX_SW_BUFFER)
    {
        if(SCBUART_CHECK_INTR_TX_MASKED(SCBUART_INTR_TX_NOT_FULL))
        {
            /* Put data into TX FIFO */
            while(SCBUART_FIFO_SIZE != SCBUART_GET_TX_FIFO_ENTRIES)
            {
                /* Check for a room in TX software buffer */
                if(SCBUART_txBufferHead != SCBUART_txBufferTail)
                {
                    /* Move local tail index */
                    locTail = (SCBUART_txBufferTail + 1u);

                    /* Adjust local tail index */
                    if(SCBUART_TX_BUFFER_SIZE == locTail)
                    {
                        locTail = 0u;
                    }

                    /* Put data into TX FIFO */
                    SCBUART_TX_FIFO_WR_REG = SCBUART_GetWordFromTxBuffer(locTail);

                    /* Move tail index */
                    SCBUART_txBufferTail = locTail;
                }
                else
                {
                    /* TX software buffer is empty: complete transmition */
                    SCBUART_DISABLE_INTR_TX(SCBUART_INTR_TX_NOT_FULL);
                    break;
                }
            }

            SCBUART_ClearTxInterruptSource(SCBUART_INTR_TX_NOT_FULL);
        }
    }
    #endif
}


/* [] END OF FILE */
