/*******************************************************************************
* File Name: isrTC.c  
* Version 1.70
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/


#include <cydevice_trm.h>
#include <CyLib.h>
#include <isrTC.h>

#if !defined(isrTC__REMOVED) /* Check for removal by optimization */

/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START isrTC_intc` */

/* `#END` */

extern cyisraddress CyRamVectors[CYINT_IRQ_BASE + CY_NUM_INTERRUPTS];

/* Declared in startup, used to set unused interrupts to. */
CY_ISR_PROTO(IntDefaultHandler);


/*******************************************************************************
* Function Name: isrTC_Start
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void isrTC_Start(void)
{
    /* For all we know the interrupt is active. */
    isrTC_Disable();

    /* Set the ISR to point to the isrTC Interrupt. */
    isrTC_SetVector(&isrTC_Interrupt);

    /* Set the priority. */
    isrTC_SetPriority((uint8)isrTC_INTC_PRIOR_NUMBER);

    /* Enable it. */
    isrTC_Enable();
}


/*******************************************************************************
* Function Name: isrTC_StartEx
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void isrTC_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    isrTC_Disable();

    /* Set the ISR to point to the isrTC Interrupt. */
    isrTC_SetVector(address);

    /* Set the priority. */
    isrTC_SetPriority((uint8)isrTC_INTC_PRIOR_NUMBER);

    /* Enable it. */
    isrTC_Enable();
}


/*******************************************************************************
* Function Name: isrTC_Stop
********************************************************************************
*
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
void isrTC_Stop(void)
{
    /* Disable this interrupt. */
    isrTC_Disable();

    /* Set the ISR to point to the passive one. */
    isrTC_SetVector(&IntDefaultHandler);
}


/*******************************************************************************
* Function Name: isrTC_Interrupt
********************************************************************************
*
* Summary:
*   The default Interrupt Service Routine for isrTC.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
CY_ISR(isrTC_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START isrTC_Interrupt` */

    /* `#END` */
}


/*******************************************************************************
* Function Name: isrTC_SetVector
********************************************************************************
*
* Summary:
*   Change the ISR vector for the Interrupt. Note calling isrTC_Start
*   will override any effect this method would have had. To set the vector 
*   before the component has been started use isrTC_StartEx instead.
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void isrTC_SetVector(cyisraddress address)
{
    CyRamVectors[CYINT_IRQ_BASE + isrTC__INTC_NUMBER] = address;
}


/*******************************************************************************
* Function Name: isrTC_GetVector
********************************************************************************
*
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*******************************************************************************/
cyisraddress isrTC_GetVector(void)
{
    return CyRamVectors[CYINT_IRQ_BASE + isrTC__INTC_NUMBER];
}


/*******************************************************************************
* Function Name: isrTC_SetPriority
********************************************************************************
*
* Summary:
*   Sets the Priority of the Interrupt. Note calling isrTC_Start
*   or isrTC_StartEx will override any effect this method would 
*   have had. This method should only be called after isrTC_Start or 
*   isrTC_StartEx has been called. To set the initial
*   priority for the component use the cydwr file in the tool.
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 3, 0 being the highest.
*
* Return:
*   None
*
*******************************************************************************/
void isrTC_SetPriority(uint8 priority)
{
	uint8 interruptState;
    uint32 priorityOffset = ((isrTC__INTC_NUMBER % 4u) * 8u) + 6u;
    
	interruptState = CyEnterCriticalSection();
    *isrTC_INTC_PRIOR = (*isrTC_INTC_PRIOR & (uint32)(~isrTC__INTC_PRIOR_MASK)) |
                                    ((uint32)priority << priorityOffset);
	CyExitCriticalSection(interruptState);
}


/*******************************************************************************
* Function Name: isrTC_GetPriority
********************************************************************************
*
* Summary:
*   Gets the Priority of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Priority of the interrupt. 0 - 3, 0 being the highest.
*
*******************************************************************************/
uint8 isrTC_GetPriority(void)
{
    uint32 priority;
	uint32 priorityOffset = ((isrTC__INTC_NUMBER % 4u) * 8u) + 6u;

    priority = (*isrTC_INTC_PRIOR & isrTC__INTC_PRIOR_MASK) >> priorityOffset;

    return (uint8)priority;
}


/*******************************************************************************
* Function Name: isrTC_Enable
********************************************************************************
*
* Summary:
*   Enables the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void isrTC_Enable(void)
{
    /* Enable the general interrupt. */
    *isrTC_INTC_SET_EN = isrTC__INTC_MASK;
}


/*******************************************************************************
* Function Name: isrTC_GetState
********************************************************************************
*
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   1 if enabled, 0 if disabled.
*
*******************************************************************************/
uint8 isrTC_GetState(void)
{
    /* Get the state of the general interrupt. */
    return ((*isrTC_INTC_SET_EN & (uint32)isrTC__INTC_MASK) != 0u) ? 1u:0u;
}


/*******************************************************************************
* Function Name: isrTC_Disable
********************************************************************************
*
* Summary:
*   Disables the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void isrTC_Disable(void)
{
    /* Disable the general interrupt. */
    *isrTC_INTC_CLR_EN = isrTC__INTC_MASK;
}


/*******************************************************************************
* Function Name: isrTC_SetPending
********************************************************************************
*
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void isrTC_SetPending(void)
{
    *isrTC_INTC_SET_PD = isrTC__INTC_MASK;
}


/*******************************************************************************
* Function Name: isrTC_ClearPending
********************************************************************************
*
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void isrTC_ClearPending(void)
{
    *isrTC_INTC_CLR_PD = isrTC__INTC_MASK;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
