
/**
 * @file encoder_sw_single.c
 * @author  Reiner Wehner 
 * @date    03.06.2015 - first implement
 *
 * @section LICENSE
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details at
 * https://www.gnu.org/copyleft/gpl.html
 *
 * @section implementation file for encoder functionality
 *
 * @todo
 *
 * @version 1.0
 */
				
#include "encoder_sw_single.h"

ENCODER_t myEncoder = {
    .encoderMode = 0, 
    .counterValue = INITIAL_COUNTER,
    .switchPressed = 0,
    .direction = '-', 
    .sLast = 0,
};

uint32 encScanTimer = 0;

//**************************************************************************//
//* function isrEncSw                                                      *//
//* Description: encoder button isr (if needed)                            *//
//**************************************************************************//
CY_ISR(isrEncSw){
    myEncoder.switchCount++;       //counter
    myEncoder.switchPressed = 1;   //button Flag
}

//**************************************************************************//
//* function encoder_init                                                  *//
//* Description: custom isr, start timer component, start polling timer    *//
//**************************************************************************//
void encoder_init(void){
    //button isr (if needed)
    isrEncSw_StartEx(isrEncSw);
    
    //start the SysTimers-Component   
    SysTimers_Start();

    //start encoder timer
    encScanTimer = SysTimers_GetTimer(4u); //str polling timer 4*250us=1ms    
}    

//**************************************************************************//
//* function encoder_update                                                *//
//* Description: sample, decode the encoder and update counter             *//
//**************************************************************************//
uint8 encoder_update() {

    uint8 retVal = 0; //return value 0->counterValue has not changed, 1-> has changed 

    /*Encoder Timer*/
    if(SysTimers_GetTimerStatus(encScanTimer)) { //continous loop       
                
        uint8 encA = ENCA_Read();     //read phase A
        uint8 encB = ENCB_Read();     //read phase B
        
        #ifdef DEBUG    //only for oszillogram        
            TestTimer_Write(~TestTimer_Read());    //polling signal
            TestA_Write(encA);        //phase A
            TestB_Write(encB);        //phase B
        #endif 

        uint8 s = encB;               //stati      
        
        if (encA) {s ^= 3;}           //negate bit0, if bit1 set  
        
        s -=  myEncoder.sLast;        //difference between s and last s
        if (s & 1) {                  //if bit0 set (diff is 1 or 3) 
            myEncoder.sLast += s;     //save s as sLast. s is now s-sLast -> sLast + s – sLast = s
            if (0 == myEncoder.sLast % (1 << myEncoder.encoderMode) ) {  //only the right state (1<<encoderMode) => 0,1,2->1,2,4
                myEncoder.counterValue += (s & 2) - 1;           //clear bit0 -> (0 vw; 2 bw)-1 
                myEncoder.direction = ((s & 2) >> 1) ? '+':'-';  //bit1 = encoder direction
                retVal = 1;                                      //counterValue has changed            
            }
        }
    }   
    return retVal;
}

/* [] END OF FILE */
