/**
 * @file main.c
 * @author  Reiner Wehner 
 * @date    03.06.2015 - first implement
 *
 * @section LICENSE
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details at
 * https://www.gnu.org/copyleft/gpl.html
 *
 * @section rotary encoder in PSoC 
 *          polling with timer ir
 *          decode based on the method of Peter Danegger
 *          https://www.mikrocontroller.net/articles/Drehgeber#Flankenerkennung_von_A_und_Pegelauswertung_von_B
 *
 *          SysTimers component by Mark http://joker.ccgslb.com/?app=forum&id=2492&rID=85773
 *           
 * @todo
 *
 * @version 1.0
 */
				
#include <project.h>
#include <stdio.h>
#include "encoder_sw_single.h"


//**************************************************************************//
//* defines                                                                *//
//**************************************************************************//

#define WELCOME1 "RW Rotary SW polling"
#define WELCOME2 "030615"

//**************************************************************************//
//* prototypes                                                             *//
//**************************************************************************//
void lcd_update();             //print encoder data to lcd

//**************************************************************************//
//* globals, typedefs                                                      *//
//**************************************************************************//


int main(){
    /* Place your initialization/startup code here (e.g. MyInst_Start()) */    
    //Starts the Components 
    LCD_Char_Start();               //start lcd component
    encoder_init() ;                //start polling timer, custom isr
    
    /*Welcome, version, date*/
    LCD_Char_PrintString(WELCOME1);
    LCD_Char_Position(1u, 0);   
    LCD_Char_PrintString(WELCOME2);
    CyDelay(3000u);
    LCD_Char_ClearDisplay();   
  

    CyGlobalIntEnable; /* enable global interrupts. */
        
    lcd_update();      //view initial values
    while(1){

        if (encoder_update()) {  //only if myEncoder.counterValue updated 
            lcd_update();        //print actual encoder values 
        }
        
        if (myEncoder.switchPressed){         //set encoder mode 0,1,2 ONLY for test unknown encoder detent/pulses
            myEncoder.encoderMode++;
            if (3 == myEncoder.encoderMode) { //only 3 different modes
               myEncoder.encoderMode = 0;
            }  
            //set encoder to initial values
            myEncoder.counterValue = INITIAL_COUNTER; 
            myEncoder.sLast = 0;
            
            lcd_update();                    //update encoderMode
            
            myEncoder.switchPressed = 0;     //clear encoder switch flag
        }
        
    }
}

//**************************************************************************//
//* function lcd_update                                                    *//
//* Description: print encoder data to lcd                                 *//
//**************************************************************************//



/**
 * Function:    lcd_update
 * Description:
 *     print encoder data to lcd
*/
void lcd_update() {
    char lcdRow[21];                               //empty row
    LCD_Char_Position(0u, 0u);                     //cursor to 0,0
    sprintf(lcdRow, "enc:%5u em:%1u dir:%c",       //generate string for first row
                    myEncoder.counterValue,         
                    (1 << myEncoder.encoderMode),
                    myEncoder.direction) ;
    LCD_Char_PrintString(lcdRow);                  //print row
    LCD_Char_Position(1u, 0u);                     //cursor ro row1, col0
    sprintf(lcdRow, "counts:%-10i",                //generate second row string
                    (int) (myEncoder.counterValue - INITIAL_COUNTER));
    LCD_Char_PrintString(lcdRow);                  //print second row
} 

/* [] END OF FILE */
